# Quick Start

Ecosystem Plugin for PulseChain support in Ape.

## Dependencies

- [python3](https://www.python.org/downloads) version 3.8 up to 3.11.

## Installation

### via `pip`

You can install the latest release via [`pip`](https://pypi.org/project/pip/):

```bash
pip install ape_mantle
```

### via `setuptools`

You can clone the repository and use [`setuptools`](https://github.com/pypa/setuptools) for the most up-to-date version:

```bash
git clone https://github.com/jwarmuz99/ape-mantle.git
cd ape-mantle
python3 setup.py install
```

## Quick Usage

Installing this plugin adds support for the Mantle ecosystem:

```
ape console --network mantle:mainnet
```

## Development

Please see the [contributing guide](CONTRIBUTING.md) to learn more how to contribute to this project.
Comments, questions, criticisms and pull requests are welcomed.